import { defineStore } from 'pinia'

export const useCartStore = defineStore('cart', {
  state: () => ({
    items: []
  }),
  actions: {
    addItem(item) {
      const existingItem = this.items.find(i => i.id === item.id)
      if (existingItem) {
        existingItem.quantity++
      } else {
        this.items.push({ ...item, quantity: 1 })
      }
    },
    removeItem(id) {
      const index = this.items.findIndex(i => i.id === id)
      if (index !== -1) {
        this.items.splice(index, 1)
      }
    },
    updateQuantity(id, quantity) {
      const item = this.items.find(i => i.id === id)
      if (item) {
        item.quantity = quantity
      }
    },
    clearCart() {
      this.items = []
    }
  },
  getters: {
    totalAmount() {
      return this.items.reduce((total, item) => total + parseFloat(item.price) * item.quantity, 0)
    }
  }
})